@@ -5,12 +5,13 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#include <KLocalizedString>
-#include <KConfig>
+#include "field.h"
 
+#if KCONTACTS_BUILD_DEPRECATED_SINCE(5, 88)
+#include <KConfig>
+#include <KLocalizedString>
 #include <KConfigGroup>
 #include <KSharedConfig>
-#include "field.h"
 
 using namespace KContacts;
 
@@ -65,7 +66,7 @@ public:
         Organization,
         Department,
         Note,
-        Url
+        Url,
     };
 
     int fieldId() const
@@ -235,6 +236,14 @@ QString Field::categoryLabel(int category)
 
 QString Field::value(const KContacts::Addressee &a)
 {
+
+    auto findPhone = [](const PhoneNumber::List &list, PhoneNumber::TypeFlag compareFlag) {
+        auto it = std::find_if(list.cbegin(), list.cend(), [=](const PhoneNumber &phone) {
+            return (phone.type() & ~(PhoneNumber::Pref)) == compareFlag;
+        });
+        return it;
+    };
+
     switch (d->fieldId()) {
     case Private::FormattedName:
         return a.formattedName();
@@ -272,56 +281,47 @@ QString Field::value(const KContacts::Addressee &a)
         }
     case Private::Url:
         return a.url().url().toDisplayString();
-    case Private::HomePhone:
-    {
+    case Private::HomePhone: {
         PhoneNumber::List::ConstIterator it;
 
         {
             // check for preferred number
             const PhoneNumber::List list = a.phoneNumbers(PhoneNumber::Home | PhoneNumber::Pref);
-            PhoneNumber::List::ConstIterator end(list.end());
-            for (it = list.begin(); it != end; ++it) {
-                if (((*it).type() & ~(PhoneNumber::Pref)) == PhoneNumber::Home) {
-                    return (*it).number();
-                }
+            auto it = findPhone(list, PhoneNumber::Home);
+            if (it != list.cend()) {
+                return it->number();
             }
         }
 
         {
             // check for normal home number
             const PhoneNumber::List list = a.phoneNumbers(PhoneNumber::Home);
-            PhoneNumber::List::ConstIterator end(list.end());
-            for (it = list.begin(); it != end; ++it) {
-                if (((*it).type() & ~(PhoneNumber::Pref)) == PhoneNumber::Home) {
-                    return (*it).number();
-                }
+            auto it = findPhone(list, PhoneNumber::Home);
+            if (it != list.cend()) {
+                return it->number();
             }
         }
 
         return QString();
     }
-    case Private::BusinessPhone:
-    {
+    case Private::BusinessPhone: {
         PhoneNumber::List::ConstIterator it;
 
         {
             // check for preferred number
             const PhoneNumber::List list = a.phoneNumbers(PhoneNumber::Work | PhoneNumber::Pref);
-            PhoneNumber::List::ConstIterator end(list.end());
-            for (it = list.begin(); it != end; ++it) {
-                if (((*it).type() & ~(PhoneNumber::Pref)) == PhoneNumber::Work) {
-                    return (*it).number();
-                }
+            auto it = findPhone(list, PhoneNumber::Work);
+            if (it != list.cend()) {
+                return it->number();
             }
         }
 
         {
             // check for normal work number
             const PhoneNumber::List list = a.phoneNumbers(PhoneNumber::Work);
-            for (it = list.begin(); it != list.end(); ++it) {
-                if (((*it).type() & ~(PhoneNumber::Pref)) == PhoneNumber::Work) {
-                    return (*it).number();
-                }
+            auto it = findPhone(list, PhoneNumber::Work);
+            if (it != list.cend()) {
+                return it->number();
             }
         }
 
@@ -540,17 +540,17 @@ void Field::deleteFields()
     Field::List::ConstIterator it;
 
     for (it = Private::mAllFields.constBegin(); it != Private::mAllFields.constEnd(); ++it) {
-        delete(*it);
+        delete (*it);
     }
     Private::mAllFields.clear();
 
     for (it = Private::mDefaultFields.constBegin(); it != Private::mDefaultFields.constEnd(); ++it) {
-        delete(*it);
+        delete (*it);
     }
     Private::mDefaultFields.clear();
 
     for (it = Private::mCustomFields.constBegin(); it != Private::mCustomFields.constEnd(); ++it) {
-        delete(*it);
+        delete (*it);
     }
     Private::mCustomFields.clear();
 }
@@ -576,8 +576,7 @@ void Field::saveFields(KConfigGroup &cfg, const QString &identifier, const Field
             customEntry << (*it)->d->label();
             customEntry << (*it)->d->key();
             customEntry << (*it)->d->app();
-            cfg.writeEntry(QLatin1String("KCONTACTS_CustomEntry_") + identifier + QLatin1Char('_')
-                           +QString::number(custom++), customEntry);
+            cfg.writeEntry(QLatin1String("KCONTACTS_CustomEntry_") + identifier + QLatin1Char('_') + QString::number(custom++), customEntry);
         }
     }
 
@@ -603,11 +602,9 @@ Field::List Field::restoreFields(const KConfigGroup &cfg, const QString &identif
     for (it = fieldIds.begin(); it != fieldIds.end(); ++it) {
         Private *f = nullptr;
         if ((*it) == Private::CustomField) {
-            QStringList customEntry = cfg.readEntry(QLatin1String("KCONTACTS_CustomEntry_")
-                                                    +identifier + QLatin1Char('_')
-                                                    +QString::number(custom++), QStringList());
-            f = new Private(*it, CustomCategory, customEntry[ 0 ],
-                            customEntry[ 1 ], customEntry[ 2 ]);
+            QStringList customEntry =
+                cfg.readEntry(QLatin1String("KCONTACTS_CustomEntry_") + identifier + QLatin1Char('_') + QString::number(custom++), QStringList());
+            f = new Private(*it, CustomCategory, customEntry[0], customEntry[1], customEntry[2]);
         } else {
             f = new Private(*it);
         }
@@ -634,10 +631,9 @@ bool Field::equals(Field *field)
 
 Field *Field::createCustomField(const QString &label, int category, const QString &key, const QString &app)
 {
-    Field *field = new Field(new Private(Private::CustomField,
-                                         category | CustomCategory,
-                                         label, key, app));
+    Field *field = new Field(new Private(Private::CustomField, category | CustomCategory, label, key, app));
     Private::mCustomFields.append(field);
 
     return field;
 }
+#endif
